@@ -1,4 +1,4 @@
-if [ ! -f /etc/lftp.conf ]
+if [ ! -e /etc/lftp.conf ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/lftp.conf /etc/lftp.conf
